@@ -365,6 +365,15 @@ class Dimension:
     def coordinates(self, value):
         self.subtype.coordinates = value
 
+    @property
+    def coords(self):
+        """Alias for the `coordinates` attribute."""
+        return self.coordinates
+
+    @coords.setter
+    def coords(self, value):
+        self.coordinates = value
+
     @property
     def data_structure(self):
         r"""
